<?php

namespace ThemeHouse\UserNotes;

use XF\AddOn\AbstractSetup;
use XF\AddOn\StepRunnerInstallTrait;
use XF\AddOn\StepRunnerUninstallTrait;
use XF\AddOn\StepRunnerUpgradeTrait;
use XF\Db\Schema\Alter;
use XF\Db\Schema\Create;

class Setup extends AbstractSetup
{
	use StepRunnerInstallTrait;
	use StepRunnerUpgradeTrait;
	use StepRunnerUninstallTrait;

	// ################################## INSTALL ###########################################

	public function installStep1()
	{
		$sm = $this->schemaManager();

		foreach ($this->getTables() as $tableName => $callback)
		{
			$sm->createTable($tableName, $callback);
		}
	}

	// ################################## UNINSTALL ###########################################

	public function uninstallStep1()
	{
		$sm = $this->schemaManager();

		foreach (array_keys($this->getTables()) as $tableName)
		{
			$sm->dropTable($tableName);
		}
	}

	// ################################## DATA ###########################################

	/**
	 * @return array
	 */
	protected function getTables(): array
	{
		$tables = [];

		$tables['xf_th_usernotes_usernote'] = function (Create $table) {
			$table->addColumn('user_note_id', 'int')->nullable()->autoIncrement();
			$table->addColumn('message', 'text');
			$table->addColumn('post_date', 'int')->setDefault(0);
			$table->addColumn('last_edit_date', 'int')->nullable();
			$table->addColumn('profile_user_id', 'int');
			$table->addColumn('user_id', 'int');
			$table->addColumn('username', 'varchar', 50);

			$table->addKey('profile_user_id');
			$table->addKey('user_id');
		};

		return $tables;
	}

	// ################################## UPGRADE ###########################################

	public function upgrade2000200Step1()
	{
		$this->schemaManager()->alterTable('xf_th_usernotes_usernote', function (Alter $table) {
			$table->addKey('profile_user_id');
			$table->addKey('user_id');
		});
	}
}